@@ -103,7 +103,7 @@ class NormalizeMethod(base.SingleConditionMethod):
         else:
             self.infile = args[0] # only 1 input wig file
             self.outfile = args[1] # if no arg give, could print to screen
-        self.normalization = kwargs.get("n", "TTR") # check if it is a legal method name
+        self.normalization = kwargs.get("n", "TTR") # should check if it is a legal method name
         self.combined_wig = isCombinedWig
 
         return self(self.infile,self.outfile,self.normalization)
@@ -143,11 +143,11 @@ class NormalizeMethod(base.SingleConditionMethod):
     @classmethod
     def usage_string(self):
         return """
-python %s normalize <input.wig> <output.wig> [-n TTR|betageom]
+python3 %s normalize <input.wig> <output.wig> [-n TTR|betageom]
 ---
 OR
 ---
-python %s normalize -c <input combined_wig> <output.wig> [-n TTR|betageom]
+python3 %s normalize -c <input combined_wig> <output.wig> [-n TTR|betageom]
 
         Optional Arguments:
         -n <string>     :=  Normalization method. Default: -n TTR
